
class ConjugatorError(Exception):
    pass

class ConjugationsParserError(Exception):
    pass

class ConjugationTemplateError(Exception):
    pass

class InvalidLangError(Exception):
    pass

class InvalidMoodError(Exception):
    pass

class InvalidTenseError(Exception):
    pass

class TemplateNotFoundError(Exception):
    pass

class VerbNotFoundError(Exception):
    pass

class VerbsParserError(Exception):
    pass
