# -*- coding: utf-8 -*-

VOWELS = ('a', 'e', 'i', 'o', 'u')

# This refers to grammatical person ('usted' is 3s despite being semantically 2p)
PERSONS = ('1s', '2s', '3s', '1p', '2p', '3p')

IMPERATIVE_PRESENT_PERSONS = ('2s', '1p', '2p')

PARTICIPLE_INFLECTIONS = ('ms', 'mp', 'fs', 'fp')
